@@ -1,9 +1,9 @@
 package My::Extra;
 
-use Apache::RequestIO ();  # for $r->print
-use Apache::RequestRec (); # for $r->content_type
+use Apache2::RequestIO ();  # for $r->print
+use Apache2::RequestRec (); # for $r->content_type
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 use strict;
 
@@ -18,7 +18,7 @@ sub handler {
   # data or something
   $r->print('x' x 1020 . '</body></html');
 
-  return Apache::OK;
+  return Apache2::Const::OK;
 }
 
 1;
